/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cloudhsm.model;

/**
 * Hsm Status
 */
public enum HsmStatus {
    
    PENDING("PENDING"),
    RUNNING("RUNNING"),
    UPDATING("UPDATING"),
    SUSPENDED("SUSPENDED"),
    TERMINATING("TERMINATING"),
    TERMINATED("TERMINATED"),
    DEGRADED("DEGRADED");

    private String value;

    private HsmStatus(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return HsmStatus corresponding to the value
     */
    public static HsmStatus fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("PENDING".equals(value)) {
            return HsmStatus.PENDING;
        } else if ("RUNNING".equals(value)) {
            return HsmStatus.RUNNING;
        } else if ("UPDATING".equals(value)) {
            return HsmStatus.UPDATING;
        } else if ("SUSPENDED".equals(value)) {
            return HsmStatus.SUSPENDED;
        } else if ("TERMINATING".equals(value)) {
            return HsmStatus.TERMINATING;
        } else if ("TERMINATED".equals(value)) {
            return HsmStatus.TERMINATED;
        } else if ("DEGRADED".equals(value)) {
            return HsmStatus.DEGRADED;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
    