/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.codedeploy.model;

/**
 * List State Filter Action
 */
public enum ListStateFilterAction {
    
    Include("include"),
    Exclude("exclude"),
    Ignore("ignore");

    private String value;

    private ListStateFilterAction(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return ListStateFilterAction corresponding to the value
     */
    public static ListStateFilterAction fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("include".equals(value)) {
            return ListStateFilterAction.Include;
        } else if ("exclude".equals(value)) {
            return ListStateFilterAction.Exclude;
        } else if ("ignore".equals(value)) {
            return ListStateFilterAction.Ignore;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
    