/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.directory.model;

import java.io.Serializable;

/**
 * <p>
 * Contains the results of the GetSnapshotLimits operation.
 * </p>
 */
public class GetSnapshotLimitsResult implements Serializable, Cloneable {

    /**
     * A <a>SnapshotLimits</a> object that contains the manual snapshot
     * limits for the specified directory.
     */
    private SnapshotLimits snapshotLimits;

    /**
     * A <a>SnapshotLimits</a> object that contains the manual snapshot
     * limits for the specified directory.
     *
     * @return A <a>SnapshotLimits</a> object that contains the manual snapshot
     *         limits for the specified directory.
     */
    public SnapshotLimits getSnapshotLimits() {
        return snapshotLimits;
    }
    
    /**
     * A <a>SnapshotLimits</a> object that contains the manual snapshot
     * limits for the specified directory.
     *
     * @param snapshotLimits A <a>SnapshotLimits</a> object that contains the manual snapshot
     *         limits for the specified directory.
     */
    public void setSnapshotLimits(SnapshotLimits snapshotLimits) {
        this.snapshotLimits = snapshotLimits;
    }
    
    /**
     * A <a>SnapshotLimits</a> object that contains the manual snapshot
     * limits for the specified directory.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param snapshotLimits A <a>SnapshotLimits</a> object that contains the manual snapshot
     *         limits for the specified directory.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public GetSnapshotLimitsResult withSnapshotLimits(SnapshotLimits snapshotLimits) {
        this.snapshotLimits = snapshotLimits;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getSnapshotLimits() != null) sb.append("SnapshotLimits: " + getSnapshotLimits() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getSnapshotLimits() == null) ? 0 : getSnapshotLimits().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof GetSnapshotLimitsResult == false) return false;
        GetSnapshotLimitsResult other = (GetSnapshotLimitsResult)obj;
        
        if (other.getSnapshotLimits() == null ^ this.getSnapshotLimits() == null) return false;
        if (other.getSnapshotLimits() != null && other.getSnapshotLimits().equals(this.getSnapshotLimits()) == false) return false; 
        return true;
    }
    
    @Override
    public GetSnapshotLimitsResult clone() {
        try {
            return (GetSnapshotLimitsResult) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    