/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.simplesystemsmanagement.model;

import java.io.Serializable;

/**
 * 
 */
public class ListDocumentsResult implements Serializable, Cloneable {

    /**
     * The names of the configuration documents.
     */
    private com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier> documentIdentifiers;

    /**
     * The token to use when requesting the next set of items. If there are
     * no additional items to return, the string is empty.
     */
    private String nextToken;

    /**
     * The names of the configuration documents.
     *
     * @return The names of the configuration documents.
     */
    public java.util.List<DocumentIdentifier> getDocumentIdentifiers() {
        if (documentIdentifiers == null) {
              documentIdentifiers = new com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier>();
              documentIdentifiers.setAutoConstruct(true);
        }
        return documentIdentifiers;
    }
    
    /**
     * The names of the configuration documents.
     *
     * @param documentIdentifiers The names of the configuration documents.
     */
    public void setDocumentIdentifiers(java.util.Collection<DocumentIdentifier> documentIdentifiers) {
        if (documentIdentifiers == null) {
            this.documentIdentifiers = null;
            return;
        }
        com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier> documentIdentifiersCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier>(documentIdentifiers.size());
        documentIdentifiersCopy.addAll(documentIdentifiers);
        this.documentIdentifiers = documentIdentifiersCopy;
    }
    
    /**
     * The names of the configuration documents.
     * <p>
     * <b>NOTE:</b> This method appends the values to the existing list (if
     * any). Use {@link #setDocumentIdentifiers(java.util.Collection)} or
     * {@link #withDocumentIdentifiers(java.util.Collection)} if you want to
     * override the existing values.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param documentIdentifiers The names of the configuration documents.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public ListDocumentsResult withDocumentIdentifiers(DocumentIdentifier... documentIdentifiers) {
        if (getDocumentIdentifiers() == null) setDocumentIdentifiers(new java.util.ArrayList<DocumentIdentifier>(documentIdentifiers.length));
        for (DocumentIdentifier value : documentIdentifiers) {
            getDocumentIdentifiers().add(value);
        }
        return this;
    }
    
    /**
     * The names of the configuration documents.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param documentIdentifiers The names of the configuration documents.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public ListDocumentsResult withDocumentIdentifiers(java.util.Collection<DocumentIdentifier> documentIdentifiers) {
        if (documentIdentifiers == null) {
            this.documentIdentifiers = null;
        } else {
            com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier> documentIdentifiersCopy = new com.amazonaws.internal.ListWithAutoConstructFlag<DocumentIdentifier>(documentIdentifiers.size());
            documentIdentifiersCopy.addAll(documentIdentifiers);
            this.documentIdentifiers = documentIdentifiersCopy;
        }

        return this;
    }

    /**
     * The token to use when requesting the next set of items. If there are
     * no additional items to return, the string is empty.
     *
     * @return The token to use when requesting the next set of items. If there are
     *         no additional items to return, the string is empty.
     */
    public String getNextToken() {
        return nextToken;
    }
    
    /**
     * The token to use when requesting the next set of items. If there are
     * no additional items to return, the string is empty.
     *
     * @param nextToken The token to use when requesting the next set of items. If there are
     *         no additional items to return, the string is empty.
     */
    public void setNextToken(String nextToken) {
        this.nextToken = nextToken;
    }
    
    /**
     * The token to use when requesting the next set of items. If there are
     * no additional items to return, the string is empty.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param nextToken The token to use when requesting the next set of items. If there are
     *         no additional items to return, the string is empty.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     */
    public ListDocumentsResult withNextToken(String nextToken) {
        this.nextToken = nextToken;
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getDocumentIdentifiers() != null) sb.append("DocumentIdentifiers: " + getDocumentIdentifiers() + ",");
        if (getNextToken() != null) sb.append("NextToken: " + getNextToken() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getDocumentIdentifiers() == null) ? 0 : getDocumentIdentifiers().hashCode()); 
        hashCode = prime * hashCode + ((getNextToken() == null) ? 0 : getNextToken().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ListDocumentsResult == false) return false;
        ListDocumentsResult other = (ListDocumentsResult)obj;
        
        if (other.getDocumentIdentifiers() == null ^ this.getDocumentIdentifiers() == null) return false;
        if (other.getDocumentIdentifiers() != null && other.getDocumentIdentifiers().equals(this.getDocumentIdentifiers()) == false) return false; 
        if (other.getNextToken() == null ^ this.getNextToken() == null) return false;
        if (other.getNextToken() != null && other.getNextToken().equals(this.getNextToken()) == false) return false; 
        return true;
    }
    
    @Override
    public ListDocumentsResult clone() {
        try {
            return (ListDocumentsResult) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    