/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.workspaces.model;

import java.io.Serializable;

/**
 * <p>
 * Contains information about the compute type of a WorkSpace bundle.
 * </p>
 */
public class ComputeType implements Serializable, Cloneable {

    /**
     * The name of the compute type for the bundle.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     */
    private String name;

    /**
     * The name of the compute type for the bundle.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     *
     * @return The name of the compute type for the bundle.
     *
     * @see Compute
     */
    public String getName() {
        return name;
    }
    
    /**
     * The name of the compute type for the bundle.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     *
     * @param name The name of the compute type for the bundle.
     *
     * @see Compute
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * The name of the compute type for the bundle.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     *
     * @param name The name of the compute type for the bundle.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     *
     * @see Compute
     */
    public ComputeType withName(String name) {
        this.name = name;
        return this;
    }

    /**
     * The name of the compute type for the bundle.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     *
     * @param name The name of the compute type for the bundle.
     *
     * @see Compute
     */
    public void setName(Compute name) {
        this.name = name.toString();
    }
    
    /**
     * The name of the compute type for the bundle.
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     * <p>
     * <b>Constraints:</b><br/>
     * <b>Allowed Values: </b>VALUE, STANDARD, PERFORMANCE
     *
     * @param name The name of the compute type for the bundle.
     *
     * @return A reference to this updated object so that method calls can be chained
     *         together.
     *
     * @see Compute
     */
    public ComputeType withName(Compute name) {
        this.name = name.toString();
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getName() != null) sb.append("Name: " + getName() );
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getName() == null) ? 0 : getName().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;

        if (obj instanceof ComputeType == false) return false;
        ComputeType other = (ComputeType)obj;
        
        if (other.getName() == null ^ this.getName() == null) return false;
        if (other.getName() != null && other.getName().equals(this.getName()) == false) return false; 
        return true;
    }
    
    @Override
    public ComputeType clone() {
        try {
            return (ComputeType) super.clone();
        
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                    + "even though we're Cloneable!",
                    e);
        }
        
    }

}
    