/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.workspaces.model;

/**
 * Workspace Directory State
 */
public enum WorkspaceDirectoryState {
    
    REGISTERING("REGISTERING"),
    REGISTERED("REGISTERED"),
    DEREGISTERING("DEREGISTERING"),
    DEREGISTERED("DEREGISTERED"),
    ERROR("ERROR");

    private String value;

    private WorkspaceDirectoryState(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return WorkspaceDirectoryState corresponding to the value
     */
    public static WorkspaceDirectoryState fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("REGISTERING".equals(value)) {
            return WorkspaceDirectoryState.REGISTERING;
        } else if ("REGISTERED".equals(value)) {
            return WorkspaceDirectoryState.REGISTERED;
        } else if ("DEREGISTERING".equals(value)) {
            return WorkspaceDirectoryState.DEREGISTERING;
        } else if ("DEREGISTERED".equals(value)) {
            return WorkspaceDirectoryState.DEREGISTERED;
        } else if ("ERROR".equals(value)) {
            return WorkspaceDirectoryState.ERROR;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
    